package com.yiqi.admin.controller.order;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.order.domain.OrderGoodsSku;
import com.yiqi.order.service.IOrderGoodsSkuService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 商品订单物料明细Controller
 *
 * @author ruoyi
 * @date 2023-12-06
 */
@Api(tags = "管理后台 - 商品订单物料明细")
@RestController
@RequestMapping(UrlConstants.managerApi + "/order/goodsSku")
public class OrderGoodsSkuController extends BaseController {
    @Autowired
    private IOrderGoodsSkuService orderGoodsSkuService;


    //<editor-folder desc="基础函数">
    /**
     * 查询商品订单物料明细列表
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsSku:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询商品订单物料明细列表")
    public TableDataInfo list(OrderGoodsSku orderGoodsSku) {
        startPage();
        List<OrderGoodsSku> list = orderGoodsSkuService.selectOrderGoodsSkuList(orderGoodsSku);
        return getDataTable(list);
    }

    /**
     * 导出商品订单物料明细列表
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsSku:export')")
    @Log(title = "商品订单物料明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出商品订单物料明细列表")
    public void export(HttpServletResponse response, OrderGoodsSku orderGoodsSku) {
        List<OrderGoodsSku> list = orderGoodsSkuService.selectOrderGoodsSkuList(orderGoodsSku);
        ExcelUtil<OrderGoodsSku> util = new ExcelUtil<OrderGoodsSku>(OrderGoodsSku. class);
        util.exportExcel(response, list, "商品订单物料明细数据");
    }

    /**
     * 获取商品订单物料明细详细信息
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsSku:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取商品订单物料明细详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(orderGoodsSkuService.selectOrderGoodsSkuById(id));
    }

    /**
     * 新增商品订单物料明细
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsSku:add')")
    @Log(title = "商品订单物料明细", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增商品订单物料明细")
    public AjaxResult add(@RequestBody OrderGoodsSku orderGoodsSku) {
        orderGoodsSku.setCreateById(getUserId());
        orderGoodsSku.setCreateBy(getUsername());
        return toAjax(orderGoodsSkuService.insertOrderGoodsSku(orderGoodsSku));
    }

    /**
     * 修改商品订单物料明细
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsSku:edit')")
    @Log(title = "商品订单物料明细", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改商品订单物料明细")
    public AjaxResult edit(@RequestBody OrderGoodsSku orderGoodsSku) {
        orderGoodsSku.setUpdateById(getUserId());
        orderGoodsSku.setUpdateBy(getUsername());
        return toAjax(orderGoodsSkuService.updateOrderGoodsSku(orderGoodsSku));
    }

    /**
     * 删除商品订单物料明细
     */
//    @PreAuthorize("@ss.hasPermi('order:goodsSku:remove')")
    @Log(title = "商品订单物料明细", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除商品订单物料明细")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(orderGoodsSkuService.deleteOrderGoodsSkuByIds(ids));
    }


    //</editor-folder>
}
